@@ -38,31 +38,31 @@ test_that('plot function returns a plot', {
 test_that('constant x is handled', {
   set.seed(123)
   x <- rep(1, 10)
-  expect_equal(fit.family(x)$mu.hat, 1)
+  expect_equal(fit.family(x)$mu, 1)
 })
 
 test_that('first and last points of huber family are mean and median for even samples', {
   set.seed(123)
   x <- rnorm(100)
   path <- fit.family(x, family = 'huber')
-  expect_equal(head(path$mu.hat, 1), mean(x))
-  expect_equal(tail(path$mu.hat, 1), median(x))
+  expect_equal(head(path$mu, 1), mean(x))
+  expect_equal(tail(path$mu, 1), median(x))
   w <- abs(rnorm(100))
   path.w <- fit.family(x, w, family = 'huber')
-  expect_equal(head(path.w$mu.hat, 1), weighted.mean(x, w))
-  expect_equal(tail(path.w$mu.hat, 1), weighted.median(x, w))
+  expect_equal(head(path.w$mu, 1), weighted.mean(x, w))
+  expect_equal(tail(path.w$mu, 1), weighted.median(x, w))
 })
 
 test_that('first and last points of huber family are mean and median for odd samples', {
   set.seed(123)
   x <- rnorm(99)
   path <- fit.family(x, family = 'huber')
-  expect_equal(head(path$mu.hat, 1), mean(x))
-  expect_equal(tail(path$mu.hat, 1), median(x))
+  expect_equal(head(path$mu, 1), mean(x))
+  expect_equal(tail(path$mu, 1), median(x))
   w <- abs(rnorm(99))
   path.w <- fit.family(x, w, family = 'huber')
-  expect_equal(head(path.w$mu.hat, 1), weighted.mean(x, w))
-  expect_equal(tail(path.w$mu.hat, 1), weighted.median(x, w))
+  expect_equal(head(path.w$mu, 1), weighted.mean(x, w))
+  expect_equal(tail(path.w$mu, 1), weighted.median(x, w))
 })
 
 test_that(paste('first and last points of huber family are mean and median for samples with repeated observations', .Machine$double.eps), {
@@ -70,10 +70,10 @@ test_that(paste('first and last points of huber family are mean and median for s
   x <- rnorm(10)
   x <- rep(x, 10)
   path <- fit.family(x, family = 'huber')
-  expect_equal(head(path$mu.hat, 1), mean(x))
-  expect_equal(tail(path$mu.hat, 1), median(x))
+  expect_equal(head(path$mu, 1), mean(x))
+  expect_equal(tail(path$mu, 1), median(x))
   w <- abs(rnorm(100))
   path.w <- fit.family(x, w, family = 'huber')
-  expect_equal(head(path.w$mu.hat, 1), weighted.mean(x, w))
-  expect_equal(tail(path.w$mu.hat, 1), weighted.median(x, w))
+  expect_equal(head(path.w$mu, 1), weighted.mean(x, w))
+  expect_equal(tail(path.w$mu, 1), weighted.median(x, w))
 })
